@@ -12,25 +12,25 @@ B <- matrix(runif(n*n),nrow=n)
 
 z <- gqz(A, B,"-")
 testqz(A,B,z)
-gev <- complex(real=z$alphar,imaginary=z$alphai)/z$beta  
+gev <- gevalues(z)
 all(which(Re(gev)<0) == seq_len(z$sdim))
 
 z <- gqz(A, B,"+")
 testqz(A,B,z)
-gev <- complex(real=z$alphar,imaginary=z$alphai)/z$beta
+gev <- gevalues(z)
 all(which(Re(gev)>0) == seq_len(z$sdim))
 
 z <- gqz(A, B,"S")
 testqz(A,B,z)
-gev <- complex(real=z$alphar,imaginary=z$alphai)/z$beta
+gev <- gevalues(z)
 all(which(abs(gev)<1) == seq_len(z$sdim))
 
 z <- gqz(A, B,"B")
 testqz(A,B,z)
-gev <- complex(real=z$alphar,imaginary=z$alphai)/z$beta
+gev <- gevalues(z)
 all(which(abs(gev)>1) == seq_len(z$sdim))
 
 z <- gqz(A, B,"R")
 testqz(A,B,z)
-gev <- complex(real=z$alphar,imaginary=z$alphai)/z$beta
+gev <- gevalues(z)
 all(which(abs(Im(gev)) <= 100*.Machine$double.eps) == seq_len(z$sdim)) 
